==> qtjambi-sql-6.2.8-sources.jar: io/qt/sql/QSqlRelation.java <==
package io.qt.sql;


/**
 * <p>Stores information about an SQL foreign key</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsqlrelation.html">QSqlRelation</a></p>
 */
public class QSqlRelation extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#QSqlRelation">QSqlRelation::QSqlRelation()</a></p>
     */
    public QSqlRelation(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSqlRelation instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#QSqlRelation-1">QSqlRelation::QSqlRelation(QString,QString,QString)</a></p>
     */
    public QSqlRelation(java.lang.String aTableName, java.lang.String indexCol, java.lang.String displayCol){
        super((QPrivateConstructor)null);
        initialize_native(this, aTableName, indexCol, displayCol);
    }
    
    private native static void initialize_native(QSqlRelation instance, java.lang.String aTableName, java.lang.String indexCol, java.lang.String displayCol);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#displayColumn">QSqlRelation::displayColumn()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String displayColumn(){
        return displayColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String displayColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#indexColumn">QSqlRelation::indexColumn()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String indexColumn(){
        return indexColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String indexColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#isValid">QSqlRelation::isValid()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#swap">QSqlRelation::swap(QSqlRelation&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.sql.QSqlRelation other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QSqlRelation(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QSqlRelation(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#tableName">QSqlRelation::tableName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String tableName(){
        return tableName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String tableName_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSqlRelation(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QSqlRelation clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QSqlRelation clone_native(long __this_nativeId);
}

==> qtjambi-sql-6.4.4-sources.jar: io/qt/sql/QSqlRelation.java <==
package io.qt.sql;

import io.qt.*;


/**
 * <p>Stores information about an SQL foreign key</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsqlrelation.html">QSqlRelation</a></p>
 */
public class QSqlRelation extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#QSqlRelation">QSqlRelation::QSqlRelation()</a></p>
     */
    public QSqlRelation(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSqlRelation instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#QSqlRelation-1">QSqlRelation::QSqlRelation(QString,QString,QString)</a></p>
     */
    public QSqlRelation(java.lang.@NonNull String aTableName, java.lang.@NonNull String indexCol, java.lang.@NonNull String displayCol){
        super((QPrivateConstructor)null);
        initialize_native(this, aTableName, indexCol, displayCol);
    }
    
    private native static void initialize_native(QSqlRelation instance, java.lang.String aTableName, java.lang.String indexCol, java.lang.String displayCol);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#displayColumn">QSqlRelation::displayColumn()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String displayColumn(){
        return displayColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String displayColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#indexColumn">QSqlRelation::indexColumn()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String indexColumn(){
        return indexColumn_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String indexColumn_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#isValid">QSqlRelation::isValid()const</a></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#swap">QSqlRelation::swap(QSqlRelation&amp;)</a></p>
     */
    @QtUninvokable
    public final void swap(io.qt.sql.@StrictNonNull QSqlRelation other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QSqlRelation(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QSqlRelation(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqlrelation.html#tableName">QSqlRelation::tableName()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String tableName(){
        return tableName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String tableName_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QSqlRelation(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QSqlRelation clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QSqlRelation clone_native(long __this_nativeId);
}
